# Are LLMs Danoliterate?


A benchmark tool for Generative Large Language Models in Danish.

Note: This repository is currently work-in-progress while the master's thesis is finished.
Implementations are subject to change.

## Installation

The package has been developed and used with Python 3.11.
To install the package in a base version, enabling model execution, install
```
pip install danoliterate
```

To install it with the entire suite of dependencies that were used in thesis, run 
```
make install
```

## Usage

```
python -m danoliterate do=evaluate
```
